EDuke32 Changelog Unofficial archive

Build 2834

13 July 2012 · 9 commits by 1 author · SVN

Builds by month 112 builds

Original log file · 20120713-2834.txt
------------------------------------------------------------------------
r2834 | helixhorned | 2012-07-13 11:21:00 -0700 (Fri, 13 Jul 2012) | 1 line

VP8: clamp GL texture to edge if possible, preventing potential stray lines
------------------------------------------------------------------------
r2833 | helixhorned | 2012-07-13 11:20:58 -0700 (Fri, 13 Jul 2012) | 4 lines

VP8: don't call I_ClearAllInput() before idle loop.

If input is cleared before, it can become impossible to cancel the video
when decoding and displaying a frame takes longer than a frame.
------------------------------------------------------------------------
r2832 | helixhorned | 2012-07-13 11:20:55 -0700 (Fri, 13 Jul 2012) | 1 line

VP8: collect times while playing the video and print a summary to the log afterwards.
------------------------------------------------------------------------
r2831 | helixhorned | 2012-07-13 11:20:52 -0700 (Fri, 13 Jul 2012) | 7 lines

Update LibVPX prebuilt library and headers to git commit 3eb4143fc3381497128d.

The library was built with GCC 4.6.1 and configured like
 ./configure --disable-vp8-encoder --disable-multithread --disable-spatial-resampling

On the aforementioned AMD system, this reduces the mean time for decoding a frame
from 18.2 to 15.4 ms, so IMO it's worth the somewhat hefty addition of 430 Kb.
------------------------------------------------------------------------
r2830 | helixhorned | 2012-07-13 11:20:43 -0700 (Fri, 13 Jul 2012) | 5 lines

VP8: unroll 3 planes -> packed conversion loop.

On an AMD Phenom II X4 system with generic memory modules, this brings down
the mean time for this conversion from 16.5 to 10.5 ms.
(GCC 4.6.1, optimized build)
------------------------------------------------------------------------
r2829 | helixhorned | 2012-07-13 11:20:40 -0700 (Fri, 13 Jul 2012) | 1 line

Lunatic: extend must-fail tests with a check for the expected error messages.
------------------------------------------------------------------------
r2828 | helixhorned | 2012-07-13 11:20:38 -0700 (Fri, 13 Jul 2012) | 1 line

Lunatic: overridden 'require', currently for base modules only.
------------------------------------------------------------------------
r2827 | helixhorned | 2012-07-13 11:20:35 -0700 (Fri, 13 Jul 2012) | 3 lines

Lunatic: make baselib functions used in defs.c local, be more disciplined with stack.

Also, print a backtrace if we return to C with an error.
------------------------------------------------------------------------
r2826 | helixhorned | 2012-07-13 11:20:31 -0700 (Fri, 13 Jul 2012) | 1 line

a.m32: in collect_*_sectors from the 'F menu, start query with sector under mouse
------------------------------------------------------------------------
VP8

don't call I_ClearAllInput() before idle loop.

Philipp Kutin (Helixhorned) 13 Jul 2012, 11:20 UTC−7 r2833

If input is cleared before, it can become impossible to cancel the video when decoding and displaying a frame takes longer than a frame.

Update LibVPX prebuilt library and headers to git commit 3eb4143fc3381497128d.

Philipp Kutin (Helixhorned) 13 Jul 2012, 11:20 UTC−7 r2831

The library was built with GCC 4.6.1 and configured like ./configure --disable-vp8-encoder --disable-multithread --disable-spatial-resampling On the aforementioned AMD system, this reduces the mean time for decoding a frame from 18.2 to 15.4 ms, so IMO it's worth the somewhat hefty addition of 430 Kb.

VP8

unroll 3 planes -> packed conversion loop.

Philipp Kutin (Helixhorned) 13 Jul 2012, 11:20 UTC−7 r2830

On an AMD Phenom II X4 system with generic memory modules, this brings down the mean time for this conversion from 16.5 to 10.5 ms. (GCC 4.6.1, optimized build)

make baselib functions used in defs.c local, be more disciplined with stack.

Philipp Kutin (Helixhorned) 13 Jul 2012, 11:20 UTC−7 r2827

Also, print a backtrace if we return to C with an error.